class ERROR_CODE(object):
    BAD_REQUEST_ERROR_CODE = "BAD_REQUEST_ERRORCODE"
    GATEWAY_ERROR_CODE = "GATEWAY_ERROR_CODE"
    SERVER_ERROR_CODE = "SERVER_ERROR_CODE"
    API_REQUEST_ERROR_CODE = "API_REQUEST_ERROR_CODE"